Index: /CKEditor/branches/features/aria/_source/plugins/wysiwygarea/plugin.js
===================================================================
--- /CKEditor/branches/features/aria/_source/plugins/wysiwygarea/plugin.js	(revision 4927)
+++ /CKEditor/branches/features/aria/_source/plugins/wysiwygarea/plugin.js	(revision 4928)
@@ -297,5 +297,5 @@
   							' tabIndex="-1"' +
   							' allowTransparency="true"' +
-							' role="textbox"'	 +
+							' role="region"'	 +
 							' aria-multiline="true"' 	+
 							' aria-labelledby="' + labelId + '"' +

Index: /CKEditor/branches/features/aria/_source/plugins/accessibility/plugin.js
===================================================================
--- /CKEditor/branches/features/aria/_source/plugins/accessibility/plugin.js	(revision 4927)
+++ /CKEditor/branches/features/aria/_source/plugins/accessibility/plugin.js	(revision 4928)
@@ -23,6 +23,6 @@
 			// Only Firefox3 support the "dialog" role.
 			'dialog' :	 env.gecko && CKEDITOR.env.version >= 10900,
-			// IE doesn't support editable iframe as text box.
-			'textbox' : env.gecko || ( env.ie && tagName != 'iframe' )
+			// IE doesn't support editing iframe as region.
+			'region' : env.gecko || ( env.ie && tagName != 'iframe' )
 		}[ role ];
 	}
@@ -41,5 +41,5 @@
 		// Just leave the original element untouched if
 		// the role is already supported on it.
-		if( lookupARIASupport( role, element.getName() ) )
+		if( lookupARIASupport( role, element.getName() ) !== false )
 			return element;
 